function [Pmax,mest,mnum,gconf]=aDNA_threekinds_llplot(ne,be,np,bp,ns,bs);
%plot likelihood of aDNA data as functions of parameters
%with two kinds of negative controls
%SYNTAX
%[Pmax,mest,mnum,gconf]=aDNA_threekinds_llplot(ne,be,np,bp,ns,bs);
%INPUTS
%ne is number of extraction blank trials
%be is number of extraction blank successses
%np is number of PCR blank trials
%bp is number of PCR blank successes
%ns is number of sample trials
%bs is number of sample successes
%OUTPUTS
%Pmax is max likelihood of data, using exact ML estimates
%mest is vector [theta2 theta3 gamma] exact ML estimates
%mnum is vector [theta2 theta3 gamma] numerical ML estimates (rough, by grid not optimization)
%gconf is 95% profile confidence interval for gamma
%USES
%aDNA_threekinds_loglike.m to evaluate likelihood of data given parameters
%threekinds_profile.m to get 95% CI for gamma
%NOTES
%grid size isn't adaptive for the numerical estimates, so they aren't
%reliable at extremes e.g. [100,0,100,0,100,1] will give the wrong numerical
%answers


theta2=0:0.025:1;
theta3=theta2;
gamma=theta2;
[gtheta2,gtheta3,ggamma]=meshgrid(theta2,theta3,gamma);
pi_e=gtheta2+gtheta3-gtheta2.*gtheta3;
gbeta=ggamma.*pi_e./(1-ggamma.*(1-pi_e));
[P,L]=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,gtheta2,gtheta3,gbeta);

p=P(:);
a1=gtheta2(:);
a2=gtheta3(:);
g=ggamma(:);
maxP=max(p);
ind=find(p==maxP);
maxa1=a1(ind);
maxa2=a2(ind);
maxg=g(ind);

   %choosing formula for ML estimates...
   c1=(bp/np>be/ne);
   c2=(be/ne>bs/ns);
   if ~c1 & ~c2%all positive
		mest=[(bp*ne-be*np)/(ne*(bp-np)) bp/np (be*ns-bs*ne)/(bs*(be-ne))];
	elseif c1
		c3=(bs/ns<(be+bp)/(ne+np));
		if c3
			mest=[0, (bp+bs+be)/(np+ns+ne), 0];%set theta2 and gamma to zero
		else
			mest=[0 (be+bp)/(np+ne),(ns*(be+bp)-bs*(ne+np))/(bs*(be+bp-ne-np))];%set only theta2 to zero
		end;
	elseif c2
		c4=((bs+be)/(ns+ne)<bp/np);
		if c4
			mest=[0, (bp+bs+be)/(np+ns+ne), 0];%set theta2 and gamma to zero
		else
			mest=[(bp*(ne+ns)-np*(be+bs))/((ne+ns)*(bp-np)), bp/np, 0];%set only gamma to zero
		end;
   end;
mnum=[maxa1 maxa2 maxg];

%approx 95% profile confidence interval for gamma by numerical method
OPTIONS=[];
a1=mest(1);
a2=mest(2);
g=mest(3);
pi_e=a1+a2-a1.*a2;
if pi_e==0
	b=bs/ns;
else
	b=g.*pi_e./(1-g.*(1-pi_e));
end;
[Pmax,Lmax]=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,a1,a2,b);
%for release 13:
%clo = FMINBND(@threekinds_profile,0,g,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
%chi = FMINBND(@threekinds_profile,g,1,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
clo = fminbnd('threekinds_profile',0,g,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
chi = fminbnd('threekinds_profile',g,1,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
gconf=[clo chi];

figure(1);
clf;
h=slice(gtheta2,gtheta3,ggamma,P,[mest(1)],[mest(2)],[mest(3)]);%slices at ML values
%	set(h,'edgecolor','none','facecolor','interp','facealpha','interp');%
%	alpha('color');
%	alphamap('rampup');
%	alphamap('increase',0.1);
%	colormap(hot);
xlabel('\theta_2');
ylabel('\theta_3');
zlabel('\gamma');
