function [P,L]=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,theta2,theta3,gamma);
%calculate likelihood and loglikelihood of observed ancient DNA results given parameter
%estimates, with two kinds of negative controls
%[P,L]=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,theta2,theta3,gamma);
%INPUTS
%ne is number of extraction blank trials
%be is number of extraction blank successes
%np is number of PCR blank trials
%bp is number of PCR blank successes
%ns is number of sample trials
%bs is number of sample successes
%theta2 = prob sequence given extraction contamination * prob extraction
%contamination
%theta3 = prob sequence given PCR setup contamination * prob PCR setup
%contamination
%gamma = prob sequence given authentic DNA * prob authentic DNA
%OUTPUTS
%P is likelihood of data given parameters
%L is log likelihood of data given parameters

pi_s=theta2.*theta3.*gamma+theta2+theta3+gamma-theta2.*gamma-theta3.*gamma-theta2.*theta3;
pi_e=theta2+theta3-theta2.*theta3;
P=nchoosek(np,bp).*theta3.^bp.*(1-theta3).^(np-bp).*nchoosek(ne,be).*pi_e.^be.*(1-pi_e).^(ne-be).*nchoosek(ns,bs).*pi_s.^bs.*(1-pi_s).^(ns-bs);
L=log(P);