function [Pmax,mest,mnum,gconf]=aDNA_threekinds_noc_llplot(ne,be,np,bp,ns,bs);
%plot likelihood of aDNA data as functions of parameters
%with two kinds of negative controls, excluding mixture amplifications from
%gamma2
%SYNTAX
%[maxP,mest,mnum,gconf]=aDNA_threekinds_noc_llplot(ne,be,np,bp,ns,bs);
%INPUTS
%ne is number of extraction blank trials
%be is number of extraction blank successses
%np is number of PCR blank trials
%bp is number of PCR blank successes
%ns is number of sample trials
%bs is number of sample successes
%OUTPUTS
%Pmax is max likelihood of data, using exact ML estimates
%mest is vector [theta2 theta3 gamma2] exact ML estimates
%mnum is vector [theta2 theta3 gamma2] numerical ML estimates (rough, by grid not optimization)
%gconf is 95% profile confidence interval for gamma2
%USES
%aDNA_threekinds_loglike.m to evaluate likelihood of data given parameters
%threekinds_profile_noc.m to get 95% CI for gamma2
%threekinds_noc_switchparms.m to convert from theta2, theta3, gamma2 parameterization
%to theta1, theta2, theta3 parameterization
%NOTES
%grid size isn't adaptive for the numerical estimates, so they aren't
%reliable at extremes e.g. [100,0,100,0,100,1] will give the wrong numerical
%answers


theta2=0:0.025:1;
theta3=theta2;
gamma2=theta2;
[gtheta2,gtheta3,ggamma]=meshgrid(theta2,theta3,gamma2);
pi_e=gtheta2+gtheta3-gtheta2.*gtheta3;
gtheta1=threekinds_noc_switchparms(gtheta2,gtheta3,ggamma,ns,bs);
ind=find(ggamma>(1-pi_e));
gtheta1(ind)=NaN;%constraint: gamma2<=1-pi_e because theta1<=1
[P,L]=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,gtheta2,gtheta3,gtheta1);

p=P(:);
t2=gtheta2(:);
t3=gtheta3(:);
g=ggamma(:);
maxP=max(p);
ind=find(p==maxP);
maxt2=t2(ind);
maxt3=t3(ind);
maxg=g(ind);
mnum=[maxt2 maxt3 maxg];

   %choosing formula for ML estimates...
   c1=(bp/np>be/ne);
   c2=(be/ne>bs/ns);
   if ~c1 & ~c2%all positive
		mest=[(bp*ne-be*np)/(ne*(bp-np)) bp/np (bs*ne-be*ns)/(bs*ne)];%formula A
	elseif c1
		c3=(bs/ns<(be+bp)/(ne+np));
		if c3
			mest=[0, (bp+bs+be)/(np+ns+ne), 0];%set theta2 and gamma2 to zero, formula D
		else
			mest=[0 (be+bp)/(np+ne),(bs*(ne+np)-ns*(be+bp))/(bs*(ne+np))];%set only theta2 to zero, formula B
		end;
	elseif c2
		c4=((bs+be)/(ns+ne)<bp/np);
		if c4
			mest=[0, (bp+bs+be)/(np+ns+ne), 0];%set theta2 and gamma2 to zero, formula D
		else
			mest=[(bp*(ne+ns)-np*(be+bs))/((ne+ns)*(bp-np)), bp/np, 0];%set only gamma2 to zero, formula C
		end;
   end;

%approx 95% profile confidence interval for gamma2 by numerical method
OPTIONS=[];
t2=mest(1);
t3=mest(2);
g=mest(3);
t1=threekinds_noc_switchparms(t2,t3,g,ns,bs);
[Pmax,Lmax]=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,t2,t3,t1);
%in Matlab release 13:
%clo = FMINBND(@threekinds_profile_noc,0,g,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
%chi = FMINBND(@threekinds_profile_noc,g,1,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
clo = fminbnd('threekinds_profile_noc',0,g,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
chi = fminbnd('threekinds_profile_noc',g,1,OPTIONS,ne,be,np,bp,ns,bs,Lmax);
gconf=[clo chi];

figure(1);
clf;
h=slice(gtheta2,gtheta3,ggamma,P,[mest(1)],[mest(2)],[mest(3)]);%slices at ML values
%	set(h,'edgecolor','none','facecolor','interp','facealpha','interp');
%	alpha('color');
%	alphamap('rampup');
%	alphamap('increase',0.1);
%	colormap(hot);
xlabel('\theta_2');
ylabel('\theta_3');
zlabel('\gamma_2');
