function [Pmax,mest,mnum,gconf]=aDNA_twokinds_llplot(nb,bb,ns,bs);
%plot likelihood of aDNA data as functions of parameters
%with one kind of negative control
%SYNTAX
%[Pmax,mest,mnum,gconf]=aDNA_twokinds_llplot(nb,bb,ns,bs);
%INPUTS
%nb is number of blank trials
%bb is number of blank successses
%ns is number of sample trials
%bs is number of sample successes
%OUTPUTS
%Pmax is max likelihood of data from exact ML estimate
%mest is vector [theta2 gamma] exact ML estimates
%mnum is vector [theta2 gamma] numerical ML estimates (rough, by grid not optimization)
%gconf is vector [lo hi] of profile likelihood 95% CI for gamma
%USES
%aDNA_loglike.m to evaluate likelihood of data given parameters
%twokinds_profile to get 95% CI
%NOTES
%grid size isn't adaptive for the numerical estimates, so they aren't
%reliable at extremes e.g. [100,0,100,1] will give the wrong numerical
%answers

warning off MATLAB:divideByZero;
theta2=0:0.01:1;
gamma=theta2;
[gtheta2,ggamma]=meshgrid(theta2,gamma);
[P,L]=aDNA_loglike(nb,bb,ns,bs,gtheta2,gtheta2./(1-ggamma.*(1-gtheta2)));

p=P(:);
a=gtheta2(:);
g=ggamma(:);
maxP=max(p);
ind=find(p==maxP);
maxa=a(ind);
maxg=g(ind);
mnum=[maxa maxg];

%max likelihood estimates
if (bb/nb)<(bs/ns)
	mest=[bb/nb,(bb*ns-bs*nb)/(bs*(bb-nb))];
else
	mest=[(bb+bs)/(nb+ns),0];
end;

%approx 95% profile confidence interval for gamma by numerical method
OPTIONS=[];
a=mest(1);
g=mest(2);
if a==0
	b=bs/ns;
else
	b=a*g/(1-g*(1-a));
end;
[Pmax,Lmax]=aDNA_loglike(nb,bb,ns,bs,a,a+b-a*b);
clo = fminbnd(@twokinds_profile,0,g,OPTIONS,nb,bb,ns,bs,Lmax);
chi = fminbnd(@twokinds_profile,g,1,OPTIONS,nb,bb,ns,bs,Lmax);
gconf=[clo chi];

figure(1);
clf;
mesh(gtheta2,ggamma,P);
xlabel('\theta_2');
ylabel('\gamma');
zlabel('\itP');
warning on MATLAB:divideByZero;