function [Pmax,mest,mnum,gconf]=aDNA_twokinds_noc_llplot(nb,bb,ns,bs);
%plot likelihood of aDNA data as functions of parameters
%with one kind of negative control
%estimates gamma2 in case where we want probability result comes only from
%authentic DNA (not amplification of both sample and contaminant)
%SYNTAX
%[maxP,mest,mnum,gconf]=aDNA_twokinds_noc_llplot(nb,bb,ns,bs);
%INPUTS
%nb is number of blank trials
%bb is number of blank successses
%ns is number of sample trials
%bs is number of sample successes
%OUTPUTS
%Pmax is max likelihood of data from exact ML estimate
%mest is vector [theta2 gamma2] exact ML estimates
%mnum is vector [theta2 gamma2] numerical ML estimates (rough, by grid not optimization)
%gconf is vector [lo hi] of profile likelihood 95% CI for gamma2
%USES
%aDNA_loglike.m to evaluate likelihood of data given parameters
%twokinds_profile_noc.m to get 95% CI
%NOTES
%grid size isn't adaptive for the numerical estimates, so they aren't
%reliable at extremes e.g. [100,0,100,1] will give the wrong numerical
%answers

warning off MATLAB:divideByZero;
theta2=0:0.01:1;
gamma2=theta2;
[gtheta2,ggamma]=meshgrid(theta2,gamma2);
ind=find(ggamma>(1-gtheta2));
ggamma(ind)=NaN;%constraint: gamma2<=1-theta2
[P,L]=aDNA_loglike(nb,bb,ns,bs,gtheta2,gtheta2./(1-ggamma));

p=P(:);
t=gtheta2(:);
g=ggamma(:);
maxP=max(p);
ind=find(p==maxP);
maxt=t(ind);
maxg=g(ind);
mnum=[maxt maxg];

%max likelihood estimates
if (bb/nb)<(bs/ns)
	mest=[bb/nb,(bs*nb-bb*ns)/(bs*nb)];
else
	mest=[(bb+bs)/(nb+ns),0];
end;

%approx 95% profile confidence interval for gamma by numerical method
OPTIONS=[];
t2=mest(1);
g=mest(2);
if t2==0
	t1=bs/ns;
else
	t1=t2*g/((1-g)*(1-t2));
end;
[Pmax,Lmax]=aDNA_loglike(nb,bb,ns,bs,t2,t1+t2-t1*t2);
clo = fminbnd(@twokinds_profile_noc,0,g,OPTIONS,nb,bb,ns,bs,Lmax);
chi = fminbnd(@twokinds_profile_noc,g,1,OPTIONS,nb,bb,ns,bs,Lmax);
gconf=[clo chi];

figure(1);
clf;
mesh(gtheta2,ggamma,P);
xlabel('\theta_2');
ylabel('\gamma_2');
zlabel('\itP');
warning on MATLAB:divideByZero;