function solOK=check_threek_noc_cmlsol(g,t2,t3,ne,be,np,bp,ns,bs,dev2);
%check whether a conditional max likelihood solution for theta2 and theta3 is OK:
%neither parameter negative
%both second derivatives negative
%pi_e<=(1-gamma)
%SYNTAX
%solOK=check_threek_noc_cmlsol(g,t2,t3,ne,be,np,bp,ns,bs,dev2);
%INPUTS
%g is a given value of gamma
%t2 and t3 are theta2 and theta3 (potential conditional ML estimates)
%ne is number of extraction blank trials
%be is number of extraction blank successses
%np is number of PCR blank trials
%bp is number of PCR blank successes
%ns is number of sample trials
%bs is number of sample successes
%if dev2 (optional) is zero, don't do second deriv tests
%(default dev2=1)
%OUTPUTS
%solOK is true if
%neither parameter negative
%both second derivatives negative
%pi_e<=(1-gamma)

if nargin<10
	dev2=1;
end;
if dev2
%second derivatives of conditional ml solutions for theta2 and theta3, from Maple
d2t2 = -(-4*bs*t2-4*bs*t3+ns*t3^2+ns*t2^2-2*ns*t3^3-8*ns*t2^2*t3+10*ns*t3^3*t2+19*ns*t2^2*t3^2-18*ns*t3^3*t2^2+5*be*t3^2-4*be*t2-4*be*t3-16*be*t2*t3^2+14*be*t2*t3-8*ne*t3^2*t2-14*be*g*t2*t3+14*bs*t2*t3+2*ns*t2*t3+5*bs*t3^2-16*bs*t2*t3^2-8*ns*t3^2*t2+ne*t3^2+ne*t2^2-2*ne*t3^3+2*ne*t2*t3-8*ne*t2^2*t3+19*ne*t3^2*t2^2+10*ne*t3^3*t2-18*ne*t3^3*t2^2-4*ne*g*t2*t3+6*be*g*t3-2*ne*t3^2*g+10*ne*t3^2*g*t2-2*be*g+8*be*t2^2*t3*g+bs*g^2*t3^2+6*bs*t2^2*t3^3*g+bs*t2^2*t3^2*g^2-2*bs*t2^2*t3*g^2-6*bs*t2^3*g*t3+6*bs*t2^3*g*t3^2-2*bs*t2^3*t3^3*g+bs*g^2*t2^2-6*bs*g*t2^2+17*bs*t2^2*t3^2-16*bs*t2^2*t3+2*bs*g*t3^3+bs+be-6*bs*t3^3*t2^2+6*bs*t2^3*t3-6*bs*t2^3*t3^2+2*bs*t2^3*t3^3+2*bs*t2^3*g-2*bs*g^2*t2+bs*g^2-2*bs*g^2*t3-4*ns*t2^4*t3-18*ns*t2^3*t3^2+14*ns*t2^3*t3^3-4*ns*t2^4*t3^3-4*ns*t2*t3^4+6*ns*t2^2*t3^4-4*ns*t2^3*t3^4+ns*t2^4*t3^4-4*be*t2^2*t3^2*g-2*bs*t2^3-16*be*t2^2*t3-2*be*t2^3-18*bs*g*t2*t3-6*bs*g*t3^2+18*bs*g*t2*t3^2+17*be*t2^2*t3^2-2*bs*g+18*bs*t2^2*t3*g+6*bs*g*t2+6*bs*g*t3+10*ns*t2^3*t3+6*ns*t2^4*t3^2-4*be*g*t3^2-2*ns*t2^3+ns*t3^4+ns*t2^4+2*ne*g*t2^3-4*ne*t2^4*t3^3+ne*t3^4*t2^4+6*be*g*t2-2*be*g^2*t2+6*ne*t3^2*t2^4-18*ne*t3^2*t2^3-4*ne*t3^4*t2^3+14*ne*t3^3*t2^3+10*ne*t2^3*t3-4*ne*t2^4*t3+ne*g^2*t2^2-2*ne*g*t2^2+6*ne*t3^4*t2^2-4*ne*t3^4*t2-2*be*t3*g^2+ne*t3^2*g^2+ne*t3^4+be*g^2-2*ne*t3*g^2*t2^2-6*ne*t3^3*g*t2-2*ne*t3^2*g^2*t2+2*ne*t3*g^2*t2+10*ne*t3*g*t2^2+6*ne*t3^3*t2^2*g-14*ne*t3^2*t2^2*g+ne*t3^2*t2^2*g^2+5*bs*t2^2-2*bs*t3^3-2*bs*g^2*t3^2*t2+4*bs*g^2*t3*t2-6*bs*t3^3*g*t2-18*bs*t2^2*t3^2*g+6*bs*t3^3*t2+5*be*t2^2-2*be*t3^3+6*be*t3^3*t2-4*be*g*t2^2+6*be*t2^3*t3-6*be*t2^3*t3^2+2*be*t2^3*t3^3-6*be*t3^3*t2^2+2*ne*t3^3*g+8*be*g*t2*t3^2+2*be*g^2*t3*t2-6*ne*g*t2^3*t3-2*ne*g*t2^3*t3^3+6*ne*g*t2^3*t3^2+ne*t2^4-2*ne*t2^3)/(-1+t2)^2/(-t2-t3+t2*t3)^2/(t2-t2*t3+t3+g-1)^2;

d2t3 = -(-12*bp*t2*t3^2+2*ns*t3^3*t2+ns*t2^2*t3^2-8*ns*t3^3*t2^2+be*t3^2-4*be*t2*t3^2+bs*t3^2-4*bs*t2*t3^2+ne*t3^2*t2^2+2*ne*t3^3*t2-8*ne*t3^3*t2^2+ne*t3^6*t2^4+2*bs*t2^3*t3^5+bs*g^2*t3^2+18*bs*t2^2*t3^3*g-2*bs*t2^2*t3^3*g^2+bs*t2^2*t3^2*g^2-18*bs*t2^2*t3^4*g+bs*t2^2*t3^4*g^2-6*bs*g*t3^5*t2+6*bs*g*t3^5*t2^2+2*bs*t2^3*g*t3^2-6*bs*t2^3*t3^3*g-16*bs*t2*t3^4+17*bs*t2^2*t3^4+bs*g^2*t3^4-6*bs*t2^3*t3^4+5*bs*t2^2*t3^2+6*bs*g*t3^3-6*bs*g*t3^4-2*bs*g^2*t3^3-16*bs*t3^3*t2^2+2*bs*g*t3^5-2*bs*t2^3*t3^2+6*bs*t2^3*t3^3+6*bs*t3^5*t2-6*bs*t3^5*t2^2+6*bs*g*t2^3*t3^4-2*bs*t2^3*t3^5*g-2*ns*t2^3*t3^2+10*ns*t2^3*t3^3-4*ns*t2^4*t3^3+10*ns*t3^5*t2-18*ns*t3^5*t2^2+35*bp*t2^2*t3^2+bp*t3^2+bp*t2^2-10*bp*t2^2*t3+2*bp*t2*t3+np*t2^2*t3^2+2*np*t3^3*t2-8*np*t3^3*t2^2-8*ns*t2*t3^4+19*ns*t2^2*t3^4-4*ns*t3^6*t2+6*ns*t3^6*t2^2-18*ns*t2^3*t3^4+6*ns*t2^4*t3^4+14*ns*t2^3*t3^5-4*ns*t2^4*t3^5-4*ns*t3^6*t2^3+ns*t3^6*t2^4-4*be*t2^2*t3^2*g+8*be*t2*t3^4*g+8*be*t2^2*t3^3*g-4*bp*g*t2*t3-2*bs*g*t3^2+6*bs*g*t2*t3^2+5*be*t2^2*t3^2+5*bp*t3^4-4*be*t2^2*t3^4*g+ns*t2^4*t3^2+bp*t2^4-2*bp*t3^5-4*bp*g*t3^4+8*bp*t3^5*t2-12*bp*t3^5*t2^2+14*bp*t2^3*t3+14*bp*t2^4*t3^2-6*bp*t2^4*t3-38*bp*t2^3*t3^2+50*bp*t2^3*t3^3-16*bp*t2^4*t3^3+4*bp*g*t2^3*t3^4-10*bp*t2^3*g*t3+18*bp*t2^3*g*t3^2-14*bp*t2^3*t3^3*g-32*bp*t2^3*t3^4+9*bp*t2^4*t3^4+8*bp*t2^3*t3^5-2*bp*t2^4*t3^5+5*bp*t2^2*t3^2*g^2-12*bp*t2^2*t3^4*g+12*bp*t2*t3^4*g-34*bp*t2^2*t3^2*g+34*bp*t2^2*t3^3*g-2*bp*t2^2*t3^3*g^2-26*bp*t3^3*g*t2+4*bp*g^2*t3^3*t2-24*bp*t2*t3^4+42*bp*t2^2*t3^4+26*bp*t3^3*t2-2*bp*g*t3^2+bp*g^2*t3^2-56*bp*t3^3*t2^2+6*np*t3^6*t2^2+14*np*t2^3*t3^5-4*np*t3^6*t2+19*np*t2^2*t3^4-2*np*t2^3*t3^2-18*np*t2^2*t3^5-4*np*t2^4*t3^3+np*t2^4*t3^2+10*np*t2^3*t3^3-18*np*t2^3*t3^4+np*t3^6+6*bp*g*t3^3-2*bp*t2^3-4*bp*t3^3+2*bp*g*t2^3-2*np*g*t3^4+2*np*g*t3^5-8*np*t3^4*t2+10*np*t3^5*t2-6*np*g*t3^5*t2+np*t3^4-2*np*t3^5+18*bp*g*t2*t3^2-6*bp*g^2*t3^2*t2+2*bp*g^2*t3*t2+14*bp*t2^2*t3*g-4*bp*t2^2*t3*g^2+10*np*g*t3^3*t2^2-4*np*g*t3^3*t2+10*np*g*t3^4*t2+bp*g^2*t2^2-2*bp*g*t2^2-2*np*t2^2*t3^2*g+np*t2^2*t3^2*g^2-2*ne*g*t2^3*t3^5-4*np*t3^5*t2^4+6*np*g*t2^3*t3^4-2*np*g*t3^5*t2^3+6*np*g*t2^2*t3^5-6*np*g*t2^3*t3^3-14*np*g*t3^4*t2^2+2*np*g*t3^2*t2^3-2*bp*g^2*t3^3-4*np*t2^3*t3^6+6*np*t2^4*t3^4+6*be*g*t3^3-4*be*g*t3^4-2*be*g^2*t3^3-2*be*g*t3^2+be*g^2*t3^2+np*t3^6*t2^4+ns*t3^4-2*ns*t3^5+ns*t3^6-4*ne*t3^6*t2^3-4*ne*t3^5*t2^4+2*ne*t3^5*g-4*ne*t2^4*t3^3+14*ne*t2^3*t3^5+6*ne*t3^4*t2^4+ne*t3^2*t2^4-2*ne*t3^2*t2^3+10*ne*t3^5*t2-4*ne*t3^6*t2-18*ne*t3^4*t2^3+10*ne*t3^3*t2^3-18*ne*t3^5*t2^2+6*ne*t3^6*t2^2+19*ne*t3^4*t2^2-8*ne*t3^4*t2-2*ne*t3^4*g+ne*t3^4*g^2+ne*t3^4-4*ne*t3^3*g*t2+2*ne*t3^3*g^2*t2+10*ne*t3^3*t2^2*g-2*ne*t3^2*t2^2*g-2*ne*t3^3*t2^2*g^2+ne*t3^2*t2^2*g^2+10*ne*t3^4*g*t2-2*ne*t3^4*g^2*t2-14*ne*t3^4*t2^2*g+ne*t3^4*t2^2*g^2-2*np*g^2*t3^3*t2^2+np*g^2*t3^4+2*np*g^2*t3^3*t2-2*np*g^2*t2*t3^4+np*g^2*t3^4*t2^2-4*bs*t3^3+5*bs*t3^4-2*bs*t3^5-2*bs*g^2*t3^2*t2-18*bs*t3^3*g*t2+4*bs*g^2*t3^3*t2+18*bs*t2*t3^4*g-2*bs*t2*t3^4*g^2-6*bs*t2^2*t3^2*g+14*bs*t3^3*t2-4*be*t3^3+5*be*t3^4-2*be*t3^5+14*be*t3^3*t2-16*be*t2*t3^4+17*be*t2^2*t3^4-6*be*t2^3*t3^4+2*be*t2^3*t3^5-2*be*t2^3*t3^2+6*be*t2^3*t3^3+6*be*t3^5*t2-6*be*t3^5*t2^2-16*be*t3^3*t2^2+6*be*g*t2*t3^2-2*be*g^2*t3^2*t2-14*be*t3^3*g*t2+2*be*g^2*t3^3*t2-6*ne*g*t2*t3^5-6*ne*g*t2^3*t3^3+2*ne*g*t2^3*t3^2+6*ne*g*t2^2*t3^5+6*ne*t3^4*g*t2^3-2*ne*t3^5+ne*t3^6)/(-1+t3)^2/t3^2/(-t2-t3+t2*t3)^2/(t2-t2*t3+t3+g-1)^2;
else%don't test  second derivs: edge solutions
	d2t2=-1;
	d2t3=-1;
end;
pi_e=t2+t3-t2*t3;
tiny=1e-10;%cope with numerical problems...
%conditions that make this a legal solution:
solOK=(t2>=-tiny & t3>=-tiny & d2t2<=tiny & d2t3<=tiny & pi_e<=(1-g+tiny));