function [t2,t3,nott2,nott3]=get_threekinds_noc_cml(g,ne,be,np,bp,ns,bs);
%get conditional ML estimates of theta2 and theta3 given gamma
%in case with two kinds of negative control
%and excluding mixtures of amplicons
%SYNTAX
%[t2,t3,nott2,nott3]=get_threekinds_noc_cml(g,ne,be,np,bp,ns,bs);
%INPUTS
%g is a given value of gamma
%ne is number of extraction blank trials
%be is number of extraction blank successses
%np is number of PCR blank trials
%bp is number of PCR blank successes
%ns is number of sample trials
%bs is number of sample successes
%OUTPUTS
%t2 and t3 are conditional ML estimates of theta2 and theta3
%nott2 and nott3 are the solution pair we didn't choose
%USES
%check_threek_noc_cmlsol to check constrained ML solutions are legal
%choose_hiL_cmL.m to choose highest likelihood solution if both legal
%threekinds_noc_edgesols to choose best edge solution if both illegal

%conditional ML estimates of theta2 and theta3 from Maple
t31 = bp/np;
%first sol
t21 = 1/2/(ns+ne)*(2*bp*ne+2*bp*ns-be*np-ns*np-ne*np+ne*g*np-bs*np+bs*g*np+...
	(bs^2*g^2*np^2+4*be*np^2*g*ns-2*bs*g*np^2*be+2*bs*np^2*g*ns-2*bs^2*g*np^2+...
	2*be*np^2*ne*g-2*ns*np^2*ne*g-2*be*np^2*ns-2*be*np^2*ne+2*be*np^2*bs+...
	2*ns*np^2*ne-2*ns*np^2*bs-2*ne^2*np^2*g-2*ne*np^2*bs+ne^2*g^2*np^2+be^2*np^2+...
	ns^2*np^2+ne^2*np^2+bs^2*np^2+2*ne*g^2*np^2*bs)^(1/2))/(-np+bp);


%second sol
t32=bp/np;
t22 = 1/2/(ns+ne)*(2*bp*ne+2*bp*ns-be*np-ns*np-ne*np+ne*g*np-bs*np+bs*g*np-...
	(bs^2*g^2*np^2+4*be*np^2*g*ns-2*bs*g*np^2*be+2*bs*np^2*g*ns-2*bs^2*g*np^2+...
	2*be*np^2*ne*g-2*ns*np^2*ne*g-2*be*np^2*ns-2*be*np^2*ne+2*be*np^2*bs+...
	2*ns*np^2*ne-2*ns*np^2*bs-2*ne^2*np^2*g-2*ne*np^2*bs+ne^2*g^2*np^2+be^2*np^2+...
	ns^2*np^2+ne^2*np^2+bs^2*np^2+2*ne*g^2*np^2*bs)^(1/2))/(-np+bp);

%which solutions do we want?
if isinf(t21) | isinf(t22) |(t21<0 & t22<0) |(isnan(t21)&isnan(t22))
   t21=0;
   t22=0;
		t31= 1/2/(np+ne+ns)*(bp+be+ne-np*g-ne*g+np+bs-bs*g+ns+(-4*ne*g*np+2*ne*g^2*bs+2*np*g^2*bs+...
			2*ne*be*g+2*ne*bp*g-2*be*bs*g+2*np*g*be+2*np*g*bp-2*ne*g*ns-2*np*g*ns+4*ns*be*g+...
			2*ns*bs*g-2*bs*np+2*ns*np-2*bp*ns+2*be*bs+2*ne*np-2*be*np-2*ns*bs-2*ns*be+bs^2*g^2+...
			bs^2-2*bs^2*g-2*np*bp-2*ne*be-2*ne*bs-2*bp*ne+be^2+np^2+ne^2*g^2+np^2*g^2-2*np^2*g+...
			2*np*g^2*ne+2*ne*ns-2*ne^2*g+ne^2+ns^2+4*bp*g*ns+2*bs*bp+2*be*bp-2*bs*g*bp+bp^2)^(1/2)); 
		t32= 1/2/(np+ne+ns)*(bp+be+ne-np*g-ne*g+np+bs-bs*g+ns-(-4*ne*g*np+2*ne*g^2*bs+2*np*g^2*bs+...
			2*ne*be*g+2*ne*bp*g-2*be*bs*g+2*np*g*be+2*np*g*bp-2*ne*g*ns-2*np*g*ns+4*ns*be*g+...
			2*ns*bs*g-2*bs*np+2*ns*np-2*bp*ns+2*be*bs+2*ne*np-2*be*np-2*ns*bs-2*ns*be+bs^2*g^2+...
			bs^2-2*bs^2*g-2*np*bp-2*ne*be-2*ne*bs-2*bp*ne+be^2+np^2+ne^2*g^2+np^2*g^2-2*np^2*g+...
			2*np*g^2*ne+2*ne*ns-2*ne^2*g+ne^2+ns^2+4*bp*g*ns+2*bs*bp+2*be*bp-2*bs*g*bp+bp^2)^(1/2));
end;
sol1OK=check_threek_noc_cmlsol(g,t21,t31,ne,be,np,bp,ns,bs);
sol2OK=check_threek_noc_cmlsol(g,t22,t32,ne,be,np,bp,ns,bs);
if sol1OK
   if ~sol2OK%choose first solution
      t2=t21;
      t3=t31;
      nott2=t22;
      nott3=t32;
   else%both solutions OK: choose the one with higher likelihood
      disp('both solutions OK');
      which=choose_hiL_cml(g,ne,be,np,bp,ns,bs,t21,t31,t22,t32);
      if which==1
         t2=t21;
	      t3=t31;
   	   nott2=t22;
      	nott3=t32;
      elseif which==2
         t2=t22;
	      t3=t32;
   	   nott2=t21;
      	nott3=t31;
	   elseif which==0%neither pair has defined likelihood
   	   t2=NaN;
      	t3=NaN;
      	nott2=NaN;
      	nott3=NaN;
      end;
   end;
elseif sol2OK%choose second solution
      t2=t22;
      t3=t32;
      nott2=t21;
      nott3=t31;
else%both bad: maybe we can get a boundary solution?
    [t2,t3]=threekinds_noc_edgesols(g,ne,be,np,bp,ns,bs);%hope these aren't vectors!
	nott2=NaN;
	nott3=NaN;
end;

