function [t2,t3]=threekinds_noc_edgesols(g,ne,be,np,bp,ns,bs);
%find edge solution with highest likelihood: two kinds of control, 
%no mixtures of amplicons
%SYNTAX
%[t2,t3]=threekinds_noc_edgesols(g,ne,be,np,bp,ns,bs);
%INPUTS
%%g is a given value of gamma
%ne is number of extraction blank trials
%be is number of extraction blank successses
%np is number of PCR blank trials
%bp is number of PCR blank successes
%ns is number of sample trials
%bs is number of sample successes
%OUTPUTS
%t2 and t3 are values of theta2 and theta3 on edges that have highest
%likelihood (may be vectors)
%USES
%aDNA_threekinds_loglike.m for likelihoods

small=0.0001;
%theta3 set to 0
t2e1=[0:small:(1-g)]';
t3e1=zeros(size(t2e1));
t1e1=t2e1.*g./((1-g).*(1-t2e1));
Pe1=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,t2e1,t3e1,t1e1);

%theta2 set to 0
t2e2=zeros(size(t2e1));
t3e2=t2e1;
t1e2=t3e2.*g./((1-g).*(1-t3e2));
Pe2=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,t3e1,t2e1,t1e1);%just swap theta2 and theta3 for edge with theta2=0;

%curve: pi_e=gamma
t2e3=t2e1;
t3e3=(1-g-t2e1)./(1-t2e1);%third edge: constraint
t1e3=1;
Pe3=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,t2e3,t3e3,t1e3);

%choose best edge solution: highest likelihood
theta2=[t2e1;t2e2;t2e3];
theta3=[t3e1;t3e2;t3e3];
P=[Pe1;Pe2;Pe3];
mp=max(P);
ind=find(P==mp);
t2=theta2(ind);
t3=theta3(ind);
