function dlli=threekinds_profile(g,ne,be,np,bp,ns,bs,Lmax);
%used in finding 95% profile likelihood confidence interval for gamma
%in case with two kinds of blank
%SYNTAX
%dlli=threekinds_profile(g,ne,be,np,bp,ns,bs,Lmax);
%INPUTS
%g is a given value of gamma
%ne is number of extraction blank trials
%be is number of extraction blank successses
%np is number of PCR blank trials
%bp is number of PCR blank successes
%ns is number of sample trials
%bs is number of sample successes
%Lmax is log likelihood from unconstrained max likelihood estimates
%OUTPUTS
%dlli is absolute difference between -2*log likelihood ratio (between full
%maximization and constrained maximization with gamma set) and critical
%chi-square value
%USES
%aDNA_threekindsloglike.m to get log likelihood

%conditional ML estimates of theta2 (called a1... here) and theta3 (called a2... here) from Maple
%first solution
a11 = 1/2/ne/g*(2*bp*ne*g-be*g*np+ns*np-ne*g*np+ne*np-bs*g*np+...
	(ns^2*np^2+ne^2*np^2-2*be*g^2*np^2*ne+2*be*g*np^2*ne+2*be*g^2*np^2*bs-...
	2*ns*np^2*ne*g-2*ne*g^2*np^2*bs+2*ne*np^2*bs*g+be^2*g^2*np^2+2*ns*np^2*ne+...
	ne^2*g^2*np^2-2*ne^2*g*np^2+bs^2*g^2*np^2-2*be*np^2*ns*g-...
	2*bs*np^2*ns*g)^(1/2))/(-np+bp);
%second solution
a12 = 1/2/ne/g*(2*bp*ne*g-be*g*np+ns*np-ne*g*np+ne*np-bs*g*np-...
	(ns^2*np^2+ne^2*np^2-2*be*g^2*np^2*ne+2*be*g*np^2*ne+2*be*g^2*np^2*bs-...
	2*ns*np^2*ne*g-2*ne*g^2*np^2*bs+2*ne*np^2*bs*g+be^2*g^2*np^2+2*ns*np^2*ne+...
	ne^2*g^2*np^2-2*ne^2*g*np^2+bs^2*g^2*np^2-2*be*np^2*ns*g-...
	2*bs*np^2*ns*g)^(1/2))/(-np+bp);
a2 = bp/np;

%which solutions do we want?
if isinf(a11) | isinf(a12) |(a11<0 & a12<0) |(isnan(a11)&isnan(a12))
		a1=0;
		a21=1/2/(np*g+ne*g)*(np*g+bp*g+ne*g-ns-ne+bs*g-np+be*g+...
			(2*ne*np-2*np^2*g+ne^2-2*bp*g^2*np+2*np*bp*g+ns^2+np^2+...
			2*ns*np+np^2*g^2+2*bs*g*np+2*bs*g^2*bp-2*ns*bp*g+2*be*g^2*bp+...
			2*bp*ne*g+2*be*g*np+bp^2*g^2-4*ne*g*np+bs^2*g^2-2*ne*g^2*bs-...
			2*ne*g^2*bp-2*ne*g^2*be+2*bs*g^2*be+2*ne*g*bs+2*ne*g*be-...
			2*ns*bs*g-2*np*g^2*bs-2*np*g^2*be+2*ns*ne-2*np*g*ns-2*ne*g*ns+...
			ne^2*g^2-2*ne^2*g-2*ns*be*g+2*np*g^2*ne+be^2*g^2)^(1/2));
		a22=1/2/(np*g+ne*g)*(np*g+bp*g+ne*g-ns-ne+bs*g-np+be*g-...
			(2*ne*np-2*np^2*g+ne^2-2*bp*g^2*np+2*np*bp*g+ns^2+np^2+...
			2*ns*np+np^2*g^2+2*bs*g*np+2*bs*g^2*bp-2*ns*bp*g+2*be*g^2*bp+...
			2*bp*ne*g+2*be*g*np+bp^2*g^2-4*ne*g*np+bs^2*g^2-2*ne*g^2*bs-...
			2*ne*g^2*bp-2*ne*g^2*be+2*bs*g^2*be+2*ne*g*bs+2*ne*g*be-...
			2*ns*bs*g-2*np*g^2*bs-2*np*g^2*be+2*ns*ne-2*np*g*ns-2*ne*g*ns+...
			ne^2*g^2-2*ne^2*g-2*ns*be*g+2*np*g^2*ne+be^2*g^2)^(1/2));
	if a21<0 & a22>=0
		a2=a22;
	elseif a21>=0 & a22<0
		a2=a21;
	elseif a21>=0 & a22>=0 & a21~=a22
		disp('both a2 solutions positive');
		a2=NaN;
	end;
else
	if a11==0 & a12==0
		a1=0;
	elseif a11<0 & a12>=0
		a1=a12;
	elseif a11>=0 & a12<0
		a1=a11;
	elseif a11>=0 & a12>=0 & a11~=a12
		disp('both a1 solutions positive');
		a1=NaN;
	end;
end;
pi_e=a1+a2-a1*a2;

b=g*pi_e/(1-g*(1-pi_e));
[P,L]=aDNA_threekinds_loglike(ne,be,np,bp,ns,bs,a1,a2,b);
crit=3.841;%chi-square (0.05, 1 d.f.)
lr2=-2*(L-Lmax);%2 log likelihood ratio
dlli=abs(lr2-crit);%difference between lr and critical chisquare
