function [dlli,L]=twokinds_profile(g,nb,bb,ns,bs,Lmax);
%used in finding 95% profile likelihood confidence interval for gamma
%in case with one kind of blank
%SYNTAX
%[dlli,L]=twokinds_profile(g,nb,bb,ns,bs,Lmax);
%INPUTS
%g is a given value of gamma
%nb is number of blank trials
%bb is number of blank successses
%ns is number of sample trials
%bs is number of sample successes
%Lmax is log likelihood from unconstrained max likelihood estimates
%OUTPUTS
%dlli is absolute difference between -2*log likelihood ratio (between full
%maximization and constrained maximization with gamma set) and critical
%chi-square value
%L is conditional likelihood given gamma
%USES
%aDNA_loglike.m to get log likelihood

%max likelihood estimate of alpha given gamma (from Maple)
warning off MATLAB:divideByZero;
a=1/2/nb/g*(-ns+nb*g+bs*g+bb*g-nb+(-2*nb*g^2*bs-2*nb*g^2*bb+2*bs*g^2*bb-2*ns*bs*g+2*nb*g*bb+2*nb*g*bs-2*ns*nb*g+bs^2*g^2+bb^2*g^2+ns^2+2*ns*nb+nb^2*g^2-2*nb^2*g+nb^2-2*ns*bb*g)^(1/2));
a2=1/2/nb/g*(-ns+nb*g+bs*g+bb*g-nb-(-2*nb*g^2*bs-2*nb*g^2*bb+2*bs*g^2*bb-2*ns*bs*g+2*nb*g*bb+2*nb*g*bs-2*ns*nb*g+bs^2*g^2+bb^2*g^2+ns^2+2*ns*nb+nb^2*g^2-2*nb^2*g+nb^2-2*ns*bb*g)^(1/2));
if a<0 
	disp('first sol negative');
	if a2>=0
		a=a2;%we want the other solution
	else
		disp('both sols negative');
	end;
end;
if a>0 & a2>0
	disp('both sols positive');
end;
if a==0
	b=bs/ns;
else
	b=a*g/(1-g*(1-a));
end;

[P,L]=aDNA_loglike(nb,bb,ns,bs,a,a+b-a*b);
crit=3.841;%chi-square (0.05, 1 d.f.)
lr2=-2*(L-Lmax);%2 log likelihood ratio
dlli=abs(lr2-crit);%difference between lr and critical chisquare
warning on MATLAB:divideByZero;