function [dlli,L]=twokinds_profile_noc(g,nb,bb,ns,bs,Lmax);
%used in finding 95% profile likelihood confidence interval for gamma
%in case with one kind of blank and where we want gamma=probability that a
%positive is amplification only of sample DNA (excluding amplifications of
%mixture of sample and contaminant)
%SYNTAX
%[dlli,L]=twokinds_profile_noc(g,nb,bb,ns,bs,Lmax);
%INPUTS
%g is a given value of gamma
%nb is number of blank trials
%bb is number of blank successses
%ns is number of sample trials
%bs is number of sample successes
%Lmax is log likelihood from unconstrained max likelihood estimates
%OUTPUTS
%dlli is absolute difference between -2*log likelihood ratio (between full
%maximization and constrained maximization with gamma set) and critical
%chi-square value
%L is conditional likelihood given gamma
%USES
%aDNA_loglike.m to get log likelihood

%max likelihood estimate of theta2 given gamma (from Maple)
warning off MATLAB:divideByZero;
t2=1/2/(nb+ns)*(bb+ns+bs+nb-nb*g-bs*g+(2*bb*bs-2*bs*nb+2*nb*g^2*bs+bb^2-2*ns*bs+bs^2-2*bs^2*g-2*nb*bb+bs^2*g^2+ns^2+2*ns*nb+nb^2-2*nb^2*g+nb^2*g^2-2*bb*bs*g-2*bb*ns+2*nb*bb*g+4*ns*bb*g+2*ns*bs*g-2*ns*nb*g)^(1/2));
t22=1/2/(nb+ns)*(bb+ns+bs+nb-nb*g-bs*g-(2*bb*bs-2*bs*nb+2*nb*g^2*bs+bb^2-2*ns*bs+bs^2-2*bs^2*g-2*nb*bb+bs^2*g^2+ns^2+2*ns*nb+nb^2-2*nb^2*g+nb^2*g^2-2*bb*bs*g-2*bb*ns+2*nb*bb*g+4*ns*bb*g+2*ns*bs*g-2*ns*nb*g)^(1/2));
if t2<0 
	if t22>=0
		t2=min(t22,1-g);%we want the other solution, with constraint 
	else
		disp('both sols negative');
		t2=0;
	end;
end;
tiny=1e-10;%need this to cope with rounding error
if t2>(1-g) & t22-(1-g)<=tiny
	t2=t22;
elseif t2-(1-g)<=tiny & t22>(1-g)
	t2=t2;
else%choose the one with higher likelihood
	if t2==0
		t1=bs/ns;
	else
		t1=t2*g/((1-g)*(1-t2));
	end;
	[P,L]=aDNA_loglike(nb,bb,ns,bs,t2,t1+t2-t1*t2);
	if t22==0
		t1=bs/ns;
	else
		t1=t22*g/((1-g)*(1-t22));
	end;
	[P2,L]=aDNA_loglike(nb,bb,ns,bs,t22,t1+t22-t1*t22);
	if P2>P
		t2=t22;
	end;
end;

if t2==0
	t1=bs/ns;
else
	t1=t2*g/((1-g)*(1-t2));
end;
[P,L]=aDNA_loglike(nb,bb,ns,bs,t2,t1+t2-t1*t2);
crit=3.841;%chi-square (0.05, 1 d.f.)
lr2=-2*(L-Lmax);%2 log likelihood ratio
dlli=abs(lr2-crit);%difference between lr and critical chisquare
warning on MATLAB:divideByZero;